Enum diem_logger::SecurityEvent [−][src]
pub enum SecurityEvent {
Show 14 variants
InvalidTransactionMempool,
InvalidNetworkEventMempool,
ConsensusInvalidMessage,
ConsensusEquivocatingVote,
InvalidConsensusProposal,
InvalidConsensusRound,
InvalidSyncInfoMsg,
InvalidRetrievedBlock,
InvalidBlock,
StateSyncInvalidChunk,
InvalidNetworkEventHC,
InvalidHealthCheckerMsg,
InvalidNetworkEvent,
NoiseHandshake,
}Variants
Mempool received a transaction from another peer with an invalid signature
Mempool received an invalid network event
Consensus received an invalid message (not well-formed, invalid vote data or incorrect signature)
Consensus received an equivocating vote
Consensus received an invalid proposal
Consensus received an invalid new round message
Consensus received an invalid sync info message
A received block is invalid
A block being committed or executed is invalid
Invalid chunk of transactions received
HealthChecker received an invalid network event
HealthChecker received an invalid message
Network received an invalid message from a remote peer
A failed noise handshake that’s either a clear bug or indicates some security issue.